#ifndef GRAPHICS_H
#define GRAPHICS_H

#include <GL/glut.h>
#include "Splines.h"
#include "FileIO.h"
#include <iostream.h>

class Graphics
{

private:
	#define BUFSIZE 256		///< The size of the selection buffer
	int mousePos[2];		///< The position of the mouse
	int movingMode;			///< Flag for when we want to move control points around
	int deleteMode;			///< Flag for when we want to delete control points
	int showMessages;		///< Flag for showing the writing on the screen
	int cameraPos[3];		///< The position of the camera in the scene

	std::vector< Splines * > spline;	///< Holds all of the spline data
	GLuint selectBuf[BUFSIZE];		///< The selection buffer
	GLint hits;				///< Number of hits in picking mode
	GLint viewport[4];			///< The viewport values
	int WindowWidth, WindowHeight;		///< The width and height of the window
	FileIO *saveData;			///< Access to saving our data to a file
	int currentLevel;			///< Current level that we are currently focusing on

public:
	/*
	 * Default constructor for a graphics object.
	 */
	Graphics(FileIO *input)
	{
		saveData = input;
		deleteMode=0;
		movingMode=0;			// We are not in pick mode
		currentLevel=0;			// Our current level is the very bottom
		showMessages=1;			// show the writing on the wall
		cameraPos[0] = 0; cameraPos[1] = 0; cameraPos[2] = 5;	// starting camera position
		
		// if we received a file name to open from the command line
		if(strcmp(input->getInputName(), "") )
			input->readFile(spline);
		else spline.push_back(new Splines());	// Initialize for level 0
	}

	/*
	 *	Very simple setup right now for OpenGL.  Lighting Initialization
	 *	should also go here.
	 */
	void DrawingSetup() {glClearColor(0.0, 0.0, 0.0, 0.0);}

	void Display();
	void Reshape(int w, int h);
	void MouseMoved(int x, int y){mousePos[0]=x; mousePos[1]=y;}
	void Mouse(int button, int state, int x, int y);
	void Idle();
	void ProcessHits(GLint hits, GLuint buffer[]);
	void DragTrack();
	void Char2Wall(float x,float y,float z, char buf[]);
	void Messages(void);
	void Keyboard(unsigned char key, int x, int y);
	void SpecialKeyboard(int key, int x, int y);

};	// end of Graphics

#endif	// GRAPHICS_H
